<?php

/******************************************************************************
 * 管理画面のクラス
 *****************************************************************************/
class SimpleAmazonAdmin {

	private $cache;
	private $setting;

	function __construct() {

		global $simple_amazon_settings;

		$this->setting = & $simple_amazon_settings;

		if ( ! $this->setting ){
			// create default options
			$this->setting = array(
				'accesskeyid'		=> '',
				'associatesid'		=> 'icoro-22',
				'delete_setting'	=> 'no',
				'imgsize'			=> 'medium',
				'layout_type'		=> 0,
				'secretaccesskey'	=> '',
				'setcss'			=> 'yes',
				'windowtarget'		=> 'self'
			);
			update_option( 'simple_amazon_admin_options', $this->setting );
		}

		$this->cache = new SimpleAmazonCacheControl();
	}

	function simple_amazon_options_page() {

		$message = "";

		if ( $_POST['action'] == 'save_options' ){
			$this->simple_amazon_save_options();
			$message .= '<div class="updated"><p><strong>設定を保存しました。</strong></p></div>' . "\n"; 
		}

		if ( $_POST['action'] == 'clear_cache' ){
			$this->cache->clear();
			$message .= '<div class="updated"><p><strong>キャッシュを削除しました。</strong></p></div>' . "\n"; 
		}

		switch( $this->setting['windowtarget']) {
			case newwin: $newwindow = ' checked'; $selfwindow = ''; break;
			default: $newwindow = ''; $selfwindow = ' checked';
		}

		switch( $this->setting['imgsize'] ) {
			case small: $s_imgsize = ' checked'; $m_imgsize = ''; $l_imgsize = ''; break;
			case large: $s_imgsize = ''; $m_imgsize = ''; $l_imgsize = ' checked'; break;
			default: $s_imgsize = ''; $m_imgsize = ' checked'; $l_imgsize = '';
		}

		switch( $this->setting['layout_type'] ) {
			case 1: $default_layout = ''; $medium_layout = ' checked'; $simple_layout = ''; $noimage_layout = ''; break;
			case 2: $default_layout  = ''; $medium_layout = ''; $simple_layout = ' checked'; $noimage_layout = ''; break;
			case 3: $default_layout  = ''; $medium_layout = ''; $simple_layout = ''; $noimage_layout = ' checked'; break;
			default: $default_layout  = ' checked';$medium_layout = '';  $simple_layout = ''; $noimage_layout = '';
		}

		switch( $this->setting['setcss']) {
			case yes: $setcss_yes = ' checked'; $setcss_no = ''; break;
			default: $setcss_yes = ''; $setcss_no = ' checked';
		}

		switch( $this->setting['delete_setting']) {
			case yes: $delete_setting_yes = ' checked'; $delete_setting_no = ''; break;
			default: $delete_setting_yes = ''; $delete_setting_no = ' checked';
		}

		// 管理画面のテンプレート
		$simple_amazon_admin_html =
			'<div class="wrap" id="footnote-options">' . "\n".
			'<h2>Simple Amazon プラグイン設定</h2>' . "\n";

		if ( $message ){
			$simple_amazon_admin_html .= $message; 
		}

		// cacheディレクトリが設定されているかチェック
		$simple_amazon_admin_html .= $this->cache->is_error();

		if( ! $this->setting['accesskeyid'] ) {
			$simple_amazon_admin_html .= '<div class="error"><p><strong>Access Key ID</strong> を設定して下さい。</p></div>' . "\n";
		}

		if( ! $this->setting['secretaccesskey'] ) {
			$simple_amazon_admin_html .= '<div class="error"><p><strong>Secret Access Key</strong> を設定して下さい。</p></div>' . "\n";
		}

		$simple_amazon_admin_html .=
			'<form method="post" action="' . $_SERVER['PHP_SELF'] . "?" . $_SERVER['QUERY_STRING'] . '">' .
			'<input type="hidden" name="action" value="save_options" />' .
			'<h3>基本設定</h3>' . "\n" .
			'<table class="form-table">' . "\n" .

			'<tr>' . "\n" .
			'<th>Access Key ID</th>' . "\n" .
			'<td><input type="text" size="22" name="accesskeyid" value="' . $this->setting['accesskeyid'] . '" /></td>' . "\n" .
			'</tr>' . "\n" .

			'<tr>' . "\n" .
			'<th>Secret Access Key</th>' . "\n" .
			'<td><input type="text" size="42" name="secretaccesskey" value="' . $this->setting['secretaccesskey'] . '" /></td>' . "\n" .
			'</tr>' . "\n" .

			'</table>' . "\n" .

			'<h3>オプション設定</h3>' . "\n" .
			'<table class="form-table">' . "\n" .

			'<tr>' . "\n" .
			'<th>あなたのアソシエイト ID</th>' . "\n" .
			'<td><input type="text" name="associatesid" value="' . $this->setting['associatesid'] . '" /></td>' . "\n" .
			'</tr>' . "\n" .

			'<tr><th>商品リンクの動作</th>' . "\n" .
			'<td><input type="radio" name="windowtarget" value="self"' . $selfwindow . ' />&nbsp;同じウィンドウ ( target 指定なし )<br />' . "\n" .
			'<input type="radio" name="windowtarget" value="newwin"' . $newwindow . ' />&nbsp;新規ウィンドウ ( target="_blank" )</td>' . "\n" .
			'</tr>' . "\n" .

			'<tr><th>商品詳細の表示項目</th>' . "\n" .
			'<td><input type="radio" name="layout_type" value="0"' . $default_layout . ' />&nbsp;Full ( 画像、タイトル、出版社、発売時期、著者、価格、本のタイプ、ページ数、ISBN、おすすめ度。本以外はこれに準ずる項目 )<br />' . "\n" .
			'<input type="radio" name="layout_type" value="1"' . $medium_layout . ' />&nbsp;Detail ( 画像、タイトル、出版社、著者、発売時期。Fullから価格情報、コード情報、おすすめ度を省略 )<br />' . "\n" .
			'<input type="radio" name="layout_type" value="2"' . $simple_layout . ' />&nbsp;Title &amp; Image ( 画像とタイトルのみ )<br />' . "\n" .
			'<input type="radio" name="layout_type" value="3"' . $noimage_layout . ' />&nbsp;Title ( タイトルのみ )</td>' . "\n" .
			'</tr>' . "\n" .

			'<tr><th>商品画像のサイズ</th>' . "\n" .
			'<td><input type="radio" name="imgsize" value="small"' . $s_imgsize . ' />&nbsp;Small ( 最大 75 x 75px )<br />' . "\n" .
			'<input type="radio" name="imgsize" value="medium"' . $m_imgsize . ' />&nbsp;Medium ( 最大 160 x 160px )<br />' . "\n" .
			'<input type="radio" name="imgsize" value="large"' . $l_imgsize . ' />&nbsp;Large ( 最大 500 x 500px )</td>' . "\n" .
			'</tr>' . "\n" .

			'<tr><th>CSSの読み込み</th>' . "\n" .
			'<td><input type="radio" name="setcss" value="no"' . $setcss_no . ' />&nbsp;style.css ( デフォルトのCSSのみ使用 )<br />' . "\n" .
			'<input type="radio" name="setcss" value="yes"' . $setcss_yes . ' />&nbsp;simple-amazon.css ( Simple Amazon付属のCSSを使用 )</td>' . "\n" .
			'</tr>' . "\n" .

			'<tr><th>アンインストール時の処理</th>' . "\n" .
			'<td><input type="radio" name="delete_setting" value="no"' . $delete_setting_no . ' />&nbsp;設定を残す<br />' . "\n" .
			'<input type="radio" name="delete_setting" value="yes"' . $delete_setting_yes . ' />&nbsp;設定を削除する</td>' . "\n" .
			'</tr>' . "\n" .

			'</table>' . "\n" .
			'<p class="submit"><input type="submit" name="Submit" value="設定を保存 &raquo;" /></p>' . "\n" .
			'</form>' . "\n";

		$simple_amazon_admin_html .=
			'<form method="post" action="' . $_SERVER['PHP_SELF'] . "?" . $_SERVER['QUERY_STRING'] . '">' .
			'<input type="hidden" name="action" value="clear_cache" />' .
			'<h3>キャッシュの削除</h3>' . "\n" .
			'<p>　保存されているキャッシュを全て削除します。</p>' . "\n" .
			'<p class="submit"><input type="submit" name="Submit" value="キャッシュを削除 &raquo;" /></p>' . "\n" .
			'</form>' . "\n" .
			'</div>' . "\n";


		echo $simple_amazon_admin_html;
	}

	function simple_amazon_add_options() {
		// Add a new menu under Options:
		add_options_page(
			'Simple Amazon',
			'Simple Amazon',
			8,
			__FILE__,
			array( &$this, 'simple_amazon_options_page' )
		);
	}
	
	function simple_amazon_save_options() {

		// create array
		$options = array(
			'associatesid'		=> trim( $_POST['associatesid'] ),
			'accesskeyid'		=> trim( $_POST['accesskeyid'] ),
			'delete_setting'	=> $_POST['delete_setting'],
			'imgsize'			=> $_POST['imgsize'],
			'layout_type'		=> $_POST['layout_type'],
			'secretaccesskey'	=> trim( $_POST['secretaccesskey'] ),
			'setcss'			=> $_POST['setcss'],
			'windowtarget'		=> $_POST['windowtarget']
		);

		update_option( 'simple_amazon_admin_options', $options );

		//cacheの削除
		$change = false;

		if( $this->setting['associatesid'] != $options['associatesid'] )	$change = true;
		if( $this->setting['imgsize'] != $options['imgsize'] )			$change = true;
		if( $this->setting['layout_type'] != $options['layout_type'] )	$change = true;

		if( $change ) {
			$this->cache->clear();
		}

		$this->setting = $options;

	}

	// 設定をデータベースから削除 //
	function uninstall() {

		global $simple_amazon_settings;

		if( $simple_amazon_settings['delete_setting'] == 'yes' ) {
			delete_option( 'simple_amazon_admin_options' );
		}
	}

}

?>