<?php

/******************************************************************************
 * キャッシュを操作するクラス
 *****************************************************************************/
class SimpleAmazonCacheControl {

	private $config;
	private $objCache;

	function __construct() {

		$this->config = array(
				'litephp_path'	=> 'Lite.php',								// Lite.phpのpath
				'cache_dir'		=> SIMPLE_AMAZON_PLUGIN_DIR . '/cache/',	// cacheディレクトリのpath
				'cache_time'	=> 60*60*24,								// cacheの有効時間(秒単位)
				'cp_path'		=> 'checkpoint.php',						// checkpoint.phpのpath
				'lock_file'		=> ''										// lockfileのpath
			);

		$this->config['lock_file'] = $this->config['cache_dir'] . 'lockfile';		// lockfileのpathを設定

		if( !class_exists('Cache_Lite') ) {
			include_once( $this->config['litephp_path'] );
		}

		$options = array(
				'cacheDir' => $this->config['cache_dir'],
				'lifeTime' => $this->config['cache_time']
			);

		$this->objCache = new Cache_Lite($options);

	}

	function is_error() {

		$error = null;

		if( file_exists($this->config['cache_dir']) ) {
			if( ! is_writable($this->config['cache_dir']) ) {
				$error = '<div class="error"><p>以下のキャッシュディレクトリのパーミッションを <strong>777</strong> (または <strong>707</strong> ) にしてください。</p>' . "\n" . '<p><code>' . $this->config['cache_dir'] . '</code></p></div>' . "\n";
			}
		} else {
			$error = '<div class="error"><p>以下のキャッシュディレクトリを作成し、パーミッションを <strong>777</strong> (または <strong>707</strong> ) にしてください。</p>' . "\n" . '<p><code>' . $this->config['cache_dir'] . '</code></p></div>' . "\n";
		}

		return $error;

	}

	function save( $feed, $id ) {

		$data = false;

		if( ! function_exists('checkpoint') ) {
			include_once( $this->config['cp_path'] );
		}

		if ( checkpoint( $this->config['lock_file'], 1 ) ) {
			if( $data = @file_get_contents($feed) )
				$this->objCache->save( $data, $id );
		}

		return $data;

	}

	function get( $id ) {
		$cache = $this->objCache->get( $id );
		return $cache;
	}

	function clear() {
		$this->objCache->clean();
		unlink( $this->config['lock_file'] );
	}

}
?>